==> jc-1.4.0.tar.gz: java/util/HashMap__24HashEntry.h <==
// class java.util.HashMap$HashEntry

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 166fe0b0ec37f0c9 java_util_AbstractMap__24BasicMapEntry
// @dep_class 5ed7b26c5166f525 java_util_HashMap__24HashEntry

// header file dependencies
// @dep_header java_util_AbstractMap__24BasicMapEntry

#include "java/util/AbstractMap__24BasicMapEntry.h"

#ifndef _JC_java_util_HashMap__24HashEntry_H_
#define _JC_java_util_HashMap__24HashEntry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_HashMap__24HashEntry$object;

// Typedefs
typedef struct _jc_java_util_HashMap__24HashEntry$sub_refs	_jc_java_util_HashMap__24HashEntry$sub_refs;
typedef struct _jc_java_util_HashMap__24HashEntry$sub_nonrefs	_jc_java_util_HashMap__24HashEntry$sub_nonrefs;
typedef struct _jc_java_util_HashMap__24HashEntry$refs	_jc_java_util_HashMap__24HashEntry$refs;
typedef struct _jc_java_util_HashMap__24HashEntry$nonrefs	_jc_java_util_HashMap__24HashEntry$nonrefs;
typedef struct _jc_java_util_HashMap__24HashEntry$object	_jc_java_util_HashMap__24HashEntry$object;

typedef const struct _jc_java_util_HashMap__24HashEntry$vmethods	_jc_java_util_HashMap__24HashEntry$vmethods;
typedef const struct _jc_java_util_HashMap__24HashEntry$vtable	_jc_java_util_HashMap__24HashEntry$vtable;
typedef const struct _jc_java_util_HashMap__24HashEntry$vtype	_jc_java_util_HashMap__24HashEntry$vtype;

// Constructors
extern void _jc_java_util_HashMap__24HashEntry$method$_init$1b34a4ef37055d19(_jc_env *, struct _jc_java_util_HashMap__24HashEntry$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern void _jc_java_util_HashMap__24HashEntry$method$access$a7b2f2b6a49a986e(_jc_env *, struct _jc_java_util_HashMap__24HashEntry$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_HashMap__24HashEntry$method$cleanup$29f5c03afa429a93(_jc_env *, struct _jc_java_util_HashMap__24HashEntry$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_HashMap__24HashEntry$method_info$access$a7b2f2b6a49a986e;
extern _jc_method _jc_java_util_HashMap__24HashEntry$method_info$cleanup$29f5c03afa429a93;

// Virtual methods structure
struct _jc_java_util_HashMap__24HashEntry$vmethods {
	void	(*access$a7b2f2b6a49a986e)(_jc_env *, struct _jc_java_util_HashMap__24HashEntry$object *);
	struct _jc_java_lang_Object$object	*(*cleanup$29f5c03afa429a93)(_jc_env *, struct _jc_java_util_HashMap__24HashEntry$object *);
};

// Vtable
struct _jc_java_util_HashMap__24HashEntry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractMap__24BasicMapEntry$vmethods	java_util_AbstractMap__24BasicMapEntry;
	_jc_java_util_HashMap__24HashEntry$vmethods	java_util_HashMap__24HashEntry;
};

// Vtype
struct _jc_java_util_HashMap__24HashEntry$vtype {
	_jc_type			type;
	_jc_java_util_HashMap__24HashEntry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_HashMap__24HashEntry$sub_refs {
	struct _jc_java_util_HashMap__24HashEntry$object	*next;
};

// Reference instance fields (object)
struct _jc_java_util_HashMap__24HashEntry$refs {
    _jc_java_util_HashMap__24HashEntry$sub_refs	java_util_HashMap__24HashEntry;
    _jc_java_util_AbstractMap__24BasicMapEntry$sub_refs	java_util_AbstractMap__24BasicMapEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_HashMap__24HashEntry$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_HashMap__24HashEntry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractMap__24BasicMapEntry$sub_nonrefs	java_util_AbstractMap__24BasicMapEntry;
    _jc_java_util_HashMap__24HashEntry$sub_nonrefs	java_util_HashMap__24HashEntry;
};

// Object instance structure
struct _jc_java_util_HashMap__24HashEntry$object {
	_jc_java_util_HashMap__24HashEntry$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_HashMap__24HashEntry$vtype	*vtype;
	_jc_java_util_HashMap__24HashEntry$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_HashMap__24HashEntry$vtype _jc_java_util_HashMap__24HashEntry$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_HashMap__24HashEntry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_HashMap__24HashEntry$class_object;

#endif	/* _JC_java_util_HashMap__24HashEntry_H_ */

==> jc-1.4.6.tar.gz: java/util/HashMap__24HashEntry.h <==
// class java.util.HashMap$HashEntry

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 166fe0b0ec37f0c9 java_util_AbstractMap__24BasicMapEntry
// @dep_class 5ed7b26c5166f525 java_util_HashMap__24HashEntry

// header file dependencies
// @dep_header java_util_AbstractMap__24BasicMapEntry

#include "java/util/AbstractMap__24BasicMapEntry.h"

#ifndef _JC_java_util_HashMap__24HashEntry_H_
#define _JC_java_util_HashMap__24HashEntry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_HashMap__24HashEntry$object;

// Typedefs
typedef struct _jc_java_util_HashMap__24HashEntry$sub_refs	_jc_java_util_HashMap__24HashEntry$sub_refs;
typedef struct _jc_java_util_HashMap__24HashEntry$sub_nonrefs	_jc_java_util_HashMap__24HashEntry$sub_nonrefs;
typedef struct _jc_java_util_HashMap__24HashEntry$refs	_jc_java_util_HashMap__24HashEntry$refs;
typedef struct _jc_java_util_HashMap__24HashEntry$nonrefs	_jc_java_util_HashMap__24HashEntry$nonrefs;
typedef struct _jc_java_util_HashMap__24HashEntry$object	_jc_java_util_HashMap__24HashEntry$object;

typedef const struct _jc_java_util_HashMap__24HashEntry$vmethods	_jc_java_util_HashMap__24HashEntry$vmethods;
typedef const struct _jc_java_util_HashMap__24HashEntry$vtable	_jc_java_util_HashMap__24HashEntry$vtable;
typedef const struct _jc_java_util_HashMap__24HashEntry$vtype	_jc_java_util_HashMap__24HashEntry$vtype;

// Constructors
extern void _jc_java_util_HashMap__24HashEntry$method$_init$1b34a4ef37055d19(_jc_env *, struct _jc_java_util_HashMap__24HashEntry$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_util_HashMap__24HashEntry$method$access$a7b2f2b6a49a986e(_jc_env *, struct _jc_java_util_HashMap__24HashEntry$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_HashMap__24HashEntry$method$cleanup$29f5c03afa429a93(_jc_env *, struct _jc_java_util_HashMap__24HashEntry$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_HashMap__24HashEntry$method_info$access$a7b2f2b6a49a986e;
extern _jc_method _jc_java_util_HashMap__24HashEntry$method_info$cleanup$29f5c03afa429a93;

// Virtual methods structure
struct _jc_java_util_HashMap__24HashEntry$vmethods {
	void	(*access$a7b2f2b6a49a986e)(_jc_env *, struct _jc_java_util_HashMap__24HashEntry$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*cleanup$29f5c03afa429a93)(_jc_env *, struct _jc_java_util_HashMap__24HashEntry$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_HashMap__24HashEntry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractMap__24BasicMapEntry$vmethods	java_util_AbstractMap__24BasicMapEntry;
	_jc_java_util_HashMap__24HashEntry$vmethods	java_util_HashMap__24HashEntry;
};

// Vtype
struct _jc_java_util_HashMap__24HashEntry$vtype {
	_jc_type			type;
	_jc_java_util_HashMap__24HashEntry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_HashMap__24HashEntry$sub_refs {
	struct _jc_java_util_HashMap__24HashEntry$object	*next;
};

// Reference instance fields (object)
struct _jc_java_util_HashMap__24HashEntry$refs {
    _jc_java_util_HashMap__24HashEntry$sub_refs	java_util_HashMap__24HashEntry;
    _jc_java_util_AbstractMap__24BasicMapEntry$sub_refs	java_util_AbstractMap__24BasicMapEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_HashMap__24HashEntry$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_HashMap__24HashEntry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractMap__24BasicMapEntry$sub_nonrefs	java_util_AbstractMap__24BasicMapEntry;
    _jc_java_util_HashMap__24HashEntry$sub_nonrefs	java_util_HashMap__24HashEntry;
};

// Object instance structure
struct _jc_java_util_HashMap__24HashEntry$object {
	_jc_java_util_HashMap__24HashEntry$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_HashMap__24HashEntry$vtype	*vtype;
	_jc_java_util_HashMap__24HashEntry$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_HashMap__24HashEntry$vtype _jc_java_util_HashMap__24HashEntry$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_HashMap__24HashEntry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_HashMap__24HashEntry$class_object;

#endif	/* _JC_java_util_HashMap__24HashEntry_H_ */
